summaryrefslogtreecommitdiff
path: root/src/code/z_sram.c
diff options
context:
space:
mode:
authorpetrie911 <69443847+petrie911@users.noreply.github.com>2021-09-20 11:51:35 -0500
committerGitHub <noreply@github.com>2021-09-20 12:51:35 -0400
commite51f50f0ff9d79cd4c19fb6519183fd00445719c (patch)
tree2151497dd9464253f6f12f069256790e7eb5c37a /src/code/z_sram.c
parent50095d427c21465b7560d7178906a3dee3eea090 (diff)
Decompile z_kankyo (#956)
* working * start color switch * progress * progress * progress on bgm func * progress * game over matched (except the rodata meme) * start update * progress * lightning docs done * progress * progress * progress * progress * progress * can compile at least * suns state, progress on kankyo_update * some new names * progress * progress * progress * new functions * cleanup * more matches * another match * now functional * format * better match * hugely improved update * cleanup/review * remove old changes * review2 * review3 * missed one * review4 * change asm filenames * update doorwarp1 * review5 * Kankyo_ -> Environment_ * format * merge master and format functions.h Co-authored-by: Jacob Young <jacobly0@users.noreply.github.com> Co-authored-by: fig <fig02srl@gmail.com> Co-authored-by: petrie911 <pmontag@DESKTOP-LG8A167.localdomain>
Diffstat (limited to 'src/code/z_sram.c')
-rw-r--r--src/code/z_sram.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/code/z_sram.c b/src/code/z_sram.c
index a9312c061..356ffee17 100644
--- a/src/code/z_sram.c
+++ b/src/code/z_sram.c
@@ -63,8 +63,8 @@ typedef struct {
/* 0x08 */ s32 cutsceneIndex;
/* 0x0C */ u16 dayTime; // "zelda_time"
/* 0x10 */ s32 nightFlag;
/* 0x14 */ s32 numDays;
/* 0x18 */ s32 unk_18; // increments with numDays, gets reset by goron for bgs and one other use
/* 0x1C */ SaveInfo info; // "information"
} Save; // size = 0x1354
@@ -161,8 +161,8 @@ void Sram_InitNewSave(void) {
SaveContext* temp = &gSaveContext;
bzero(&SAVE_INFO, sizeof(SaveInfo));
- gSaveContext.numDays = 0;
- gSaveContext.unk_18 = 0;
+ gSaveContext.totalDays = 0;
+ gSaveContext.bgsDayCount = 0;
SAVE_PLAYER_DATA = sNewSavePlayerData;
gSaveContext.equips = sNewSaveEquips;
@@ -250,8 +250,8 @@ void Sram_InitDebugSave(void) {
SaveContext* temp = &gSaveContext;
bzero(&SAVE_INFO, sizeof(SaveInfo));
- gSaveContext.numDays = 0;
- gSaveContext.unk_18 = 0;
+ gSaveContext.totalDays = 0;
+ gSaveContext.bgsDayCount = 0;
SAVE_PLAYER_DATA = sDebugSavePlayerData;
gSaveContext.equips = sDebugSaveEquips;
@@ -561,8 +561,8 @@ void Sram_VerifyAndLoadAllSaves(FileChooseContext* fileChooseCtx, SramContext* s
// note that gSaveContext.dayTime is not actually the sizeof(s32)
bzero(&gSaveContext.dayTime, sizeof(s32));
bzero(&gSaveContext.nightFlag, sizeof(s32));
- bzero(&gSaveContext.numDays, sizeof(s32));
- bzero(&gSaveContext.unk_18, sizeof(s32));
+ bzero(&gSaveContext.totalDays, sizeof(s32));
+ bzero(&gSaveContext.bgsDayCount, sizeof(s32));
if (!slotNum) {
Sram_InitDebugSave();
@@ -63,8 +63,8 @@ typedef struct {
/* 0x0C */ u16 dayTime; // "zelda_time"
/* 0x10 */ s32 nightFlag;
- /* 0x14 */ s32 numDays;
- /* 0x18 */ s32 unk_18; // increments with numDays, gets reset by goron for bgs and one other use
+ /* 0x14 */ s32 totalDays;
+ /* 0x18 */ s32 unk_18; // increments with totalDays, gets reset by goron for bgs and one other use
/* 0x1C */ SaveInfo info; // "information"
} Save; // size = 0x1354